Patch "dm: fix second blk_delay_queue() parameter to be in msec units not jiffies" has been added to the 4.7-stable tree
Subsystems (2)
This is a note to let you know that I've just added the patch titled
dm: fix second blk_delay_queue() parameter to be in msec units not jiffies
to the 4.7-stable tree which can be found at:
http://www.kernel.org/git/?p=linux/kernel/git/stable/stable-queue.git;a=summary
The filename of the patch is:
dm-fix-second-blk_delay_queue-parameter-to-be-in-msec-units-not-jiffies.patch
and it can be found in the queue-4.7 subdirectory.
If you, or anyone else, feels it should not be added to the stable tree, please let <[email protected]> know about it.
Quoted 1 line
From
bd9f55ea1cf6e14eb054b06ea877d2d1fa339514Mon Sep 17 00:00:00 2001
From: Tahsin Erdogan <[email protected]>
Date: Fri, 15 Jul 2016 06:27:08 -0700
Subject: dm: fix second blk_delay_queue() parameter to be in msec units not jiffies
From: Tahsin Erdogan <[email protected]>
commit bd9f55ea1cf6e14eb054b06ea877d2d1fa339514 upstream.
Commit d548b34b062 ("dm: reduce the queue delay used in dm_request_fn from 100ms to 10ms") always intended the value to be 10 msecs -- it just expressed it in jiffies because earlier commit 7eaceaccab ("block:
remove per-queue plugging") did.
--- drivers/md/dm.c | 2 +- 1 file changed, 1 insertion(+), 1 deletion(-)
drivers/md/dm.c +1 -1
@@ -2175,7 +2175,7 @@ static void dm_request_fn(struct request md_in_flight(md) && rq->bio && rq->bio->bi_vcnt == 1 && md->last_rq_pos == pos && md->last_rq_rw == rq_data_dir(rq)) || (ti->type->busy && ti->type->busy(ti))) { -blk_delay_queue (q,HZ /100 ); +blk_delay_queue (q,10 );return ; }
Patches currently in stable-queue which might be from [email protected] are
queue-4.7/dm-fix-second-blk_delay_queue-parameter-to-be-in-msec-units-not-jiffies.patch